
__name__ = 'notebook_autorun'
name_url = __name__.replace('_', '-')

__packages__ = [__name__]
__version__ = '0.1.3'
__description__ = 'Auto run certain cells upon notebook start - if trusted'
__author__ = 'oscar6echo'
__author_email__ = 'olivier.borderies@gmail.com'
__url__ = 'https://github.com/oscar6echo/{}'.format(name_url)
__download_url__ = 'https://github.com/oscar6echo/{}/tarball/{}'.format(name_url,
                                                                        __version__)
__keywords__ = ['python', 'display', 'javascript']
__license__ = 'MIT'
__classifiers__ = ['Development Status :: 4 - Beta',
                   'License :: OSI Approved :: MIT License',
                   'Programming Language :: Python :: 2.7',
                   'Programming Language :: Python :: 3.5',
                   'Programming Language :: Python :: 3.6'
                   ]
__include_package_data__ = True
__package_data__ = {
    'templates':
    ['templates/getCellsFromComment.js',
     'templates/getCellsFromMetadata.js',
     'templates/getCellsFromString.js',
     'templates/notice_short.md',
     'templates/notice_long.md',
     'templates/notice_safe.txt'
     ]
}




import os
import json

import jinja2 as jj

from IPython.display import display, Javascript, Markdown

from .util import is_digit


class Autorun:
    """
    """

    here = os.path.dirname(os.path.abspath(__file__))
    dir_template = os.path.join(here, 'templates')
    loader = jj.FileSystemLoader(dir_template)
    env = jj.Environment(loader=loader,
                         variable_start_string='__$',
                         variable_end_string='$__',
                         block_start_string='{%',
                         block_end_string='%}'
                         )

    def __init__(self,
                 cells=None,
                 metadata=False,
                 comment=False,
                 comment_flag='# AUTORUN',
                 verbose=True):
        """
        """
        inputs = [cells, metadata, comment]
        msg = 'Exactly one of cells/metadata/comment must be set'
        assert sum([bool(e) for e in inputs]) == 1, msg

        str_cells = self._cells_to_str(cells)
        self.data = {'str_cells': str_cells,
                     'metadata': metadata,
                     'comment': comment,
                     'comment_flag': comment_flag,
                     }
        self.verbose = verbose

    def add_js(self):
        """
        """
        template = Autorun.env.get_template('main.template.js')
        js = template.render(data=self.data)

        if self.verbose:
            template = Autorun.env.get_template('notice_safe.txt')
            txt = template.render()
            print(txt)

        display(Javascript(js))

        if self.verbose:
            template = Autorun.env.get_template('notice_short.md')
            str_data = json.dumps(self.data)
            md = template.render(str_data=str_data)
            display(Markdown(md))

    @classmethod
    def info(cls):
        """
        """
        template = Autorun.env.get_template('notice_long.md')
        md = template.render()
        display(Markdown(md))

    @staticmethod
    def _cells_to_str(cells):
        """
        """
        if cells is None:
            return None

        if isinstance(cells, list):
            str_cells = ','.join([str(e) for e in cells])
        else:
            str_cells = cells

        s = str_cells
        if ':' in str_cells:
            s = str_cells.split(':', 2)
            assert all([is_digit(e)
                        for e in s]), 'All slice elements must be integers'
            if len(s) == 3:
                assert s[2] != '0', 'Slice step cannot be zero'

        return str_cells
